"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GrowFromParent = void 0;
const DomFunctions_1 = require("../util/DomFunctions");
const gsap_1 = __importDefault(require("gsap"));
function GrowFromParent(parent, child, options) {
    var _a, _b, _c, _d, _e, _f, _g;
    let duration = (_a = options === null || options === void 0 ? void 0 : options.duration) !== null && _a !== void 0 ? _a : 0.5;
    let ease = (_b = options === null || options === void 0 ? void 0 : options.ease) !== null && _b !== void 0 ? _b : "Power1.easeOut";
    let toDirection = (_c = options === null || options === void 0 ? void 0 : options.toDirection) !== null && _c !== void 0 ? _c : "right";
    let gap = (_d = options === null || options === void 0 ? void 0 : options.gap) !== null && _d !== void 0 ? _d : 0;
    let match = ((_e = options === null || options === void 0 ? void 0 : options.match) !== null && _e !== void 0 ? _e : toDirection === "right") ? "height" : "width";
    let childWidth = (_f = options === null || options === void 0 ? void 0 : options.width) !== null && _f !== void 0 ? _f : 20;
    let childHeight = (_g = options === null || options === void 0 ? void 0 : options.height) !== null && _g !== void 0 ? _g : 20;
    const t = gsap_1.default.timeline({ defaults: { duration, ease } });
    if (match === "height") {
        childHeight = (options === null || options === void 0 ? void 0 : options.height) || DomFunctions_1.height(parent);
        child.style.width = "0";
        child.style.height = childHeight + "px";
    }
    if (match === "width") {
        childWidth = (options === null || options === void 0 ? void 0 : options.width) || DomFunctions_1.width(parent);
        child.style.height = "0";
        child.style.width = childWidth + "px";
    }
    //   Styling
    parent.style.position = "relative";
    child.style.position = "absolute";
    child.style.overflow = "hidden";
    for (const grandchild of child.children) {
        grandchild.style.opacity = "0";
    }
    if (toDirection === "right") {
        child.style.left = DomFunctions_1.width(parent) + gap + "px";
        t.to(child, { width: childWidth });
    }
    if (toDirection === "left") {
        child.style.right = DomFunctions_1.width(parent) + gap + "px";
        t.to(child, { width: childWidth });
    }
    if (toDirection === "bottom") {
        child.style.top = DomFunctions_1.height(parent) + gap + "px";
        t.to(child, { height: childHeight });
    }
    if (toDirection === "up") {
        child.style.bottom = DomFunctions_1.height(parent) + gap + "px";
        t.to(child, { height: childHeight });
    }
    t.to(child.children, {
        opacity: 1,
        duration: 0.4,
    }, "-=.2").reverse();
    t.eventCallback("onComplete", () => {
        if (options === null || options === void 0 ? void 0 : options.callback)
            options === null || options === void 0 ? void 0 : options.callback();
    });
    return {
        gsap: gsap_1.default,
        timeline: t,
        toggle: function () {
            t.reversed(!t.reversed());
        },
    };
}
exports.GrowFromParent = GrowFromParent;
